===============================
 Zoort
===============================

.. image:: https://mejorando.la/static/images/logos/mejorandola.png
        :target: https://www.mejorando.la

.. image:: https://badge.fury.io/py/zoort.png
    :target: http://badge.fury.io/py/zoort

.. image:: https://pypip.in/d/zoort/badge.png
        :target: https://crate.io/packages/zoort?version=latest

A Python script for automatic MongoDB backups

Features
--------

* Backup for just one or all your MongoDB Databases.
* Encrypt and Decrypt output dump file.
* Upload file to S3 bucket.

Requirements
------------

- Python >= 2.6 or >= 3.3

License
-------

MIT licensed. See the bundled `LICENSE <https://github.com/yograterol/zoort/blob/master/LICENSE>`_ file for more details.